
/*  ----------------------------------------------------------------------
   sf Control Panel - A management software for sf Firewall
   Copyright (C) 1997 Roland E. Schmid <schmid@acm.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

import java.applet.*;
import java.awt.*;
import sfclasses.*;

/**
 * sf Firewall Control Panel - Startup Applet
 * @version 1.0 12 Dec 1996
 * @author Roland E. Schmid
 */

public class sfRemote extends Applet {

  public void init() {

    setLayout(new BorderLayout());

    if (!Templates.initialized) {
      System.out.println("Error in Templates. Applet stopped.");
      add("Center", new Label("ERROR! See standard output."));
      return;
    }

    pn = new Panel();
    pn.setLayout(new FlowLayout(FlowLayout.LEFT));
    pc = new Panel();
    pc.setLayout(new FlowLayout(FlowLayout.LEFT));
    ps = new Panel();
    ps.setLayout(new FlowLayout());
    connectHost = new TextField(50);
    startButton = new Button("Load");
    newButton = new Button("New");
    pc.add(new Label("Firewall host name or IP address:"));
    pc.add(connectHost);
    ps.add(startButton);
    ps.add(newButton);
    pn.add(new Label("Press `Load' to load the global configuration file from the firewall."));
    add("North", pn);
    add("Center", pc);
    add("South", ps);
    requestFocus();
    connectHost.requestFocus();
  }

  public boolean action(Event evt, Object arg) {
    if (evt.target == startButton || evt.target == newButton || evt.target == connectHost) {
      if (isLaunching) {
        showStatus("Still connecting. Please wait!");
        return true;
      }
      if (isStarted) 
        if (!mgc.terminated) {
          showStatus("Application already started!");
          return true;
        }

      if (!Communicator.connectRelay()) {
        showStatus("Cannot connect to sfrelay!");
        return true;
      }
      showStatus("Connected to sfrelay.");

      isLaunching = true;
      LaunchApp la;
      if (evt.target == newButton)
        la = new LaunchApp(null, this);
      else
        la = new LaunchApp(connectHost.getText().trim(), this);
      la.start();
      return true;
    }
    else
      return super.action(evt, arg);
  }

  protected void setRunInfo(ManageControl mc, boolean is) {
    mgc = mc;
    isStarted = is;
    isLaunching = false;
  }

  // private data
  private Panel pn, pc, ps;
  private TextField connectHost;
  private Button startButton;
  private Button newButton;
  private ManageControl mgc;
  private boolean isStarted = false;
  private boolean isLaunching = false;
}

class LaunchApp extends Thread {

  public LaunchApp(String hn, sfRemote a) {
    hostname = hn;
    app = a;
  }

  public void run() {
    if (hostname != null) {
      app.showStatus("Connecting to "+hostname+". Please wait!");
      if (Communicator.resolve(hostname) == null) {
        switch (Communicator.commError) {
          case Communicator.COMM_NOCONN:
            app.showStatus("Cannot connect to sfrelay!");
            app.setRunInfo(null, false);
            return;
          case Communicator.COMM_RESOLVE:
            app.showStatus("Unknown host "+hostname);
            app.setRunInfo(null, false);
            return;
          default:
            app.showStatus("Error while checking hostname");
            app.setRunInfo(null, false);
            return;
        }
      }
    }
    ManageControl mgc = new ManageControl(hostname, app.getAppletContext());
    if (mgc.terminated) { // cannot connect to firewall host
      if (Communicator.commError == Communicator.COMM_NOCONN)
        app.showStatus("Cannot connect to sfrelay!");
      else if (Communicator.commError == Communicator.COMM_OPENCONN)
        app.showStatus("Cannot connect to "+hostname);
      else
        app.showStatus("Error while connecting to "+hostname);
      mgc = null;
      app.setRunInfo(null, false);
      return;
    }
    mgc.resize(500,350);
    mgc.show();
    if (hostname != null)
      app.showStatus("Connection to "+hostname+" established");
    app.setRunInfo(mgc, true);
  }

  private String hostname;
  private sfRemote app;

}
