
/*  ----------------------------------------------------------------------
   sf Control Panel - A management software for sf Firewall
   Copyright (C) 1997 Roland E. Schmid <schmid@acm.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

package sfclasses;

import java.awt.*;

/**
 * <b><i>About</i> Dialog Box</b><br>
 * This dialog box is displayed when the user selects About in the Help menu.
 * It contains general information about the software version and copyright.<br>
 * This is a GUI class.
 * @version 1.0 16 Dec 1996
 * @author Roland E. Schmid
 */

public class AboutDialog extends Dialog {

  /**
   * Initialize the dialog box
   * @param parent Parent frame of the dialog box.
   */
  public AboutDialog(Frame parent) {
    super(parent, "About sf Control Panel", true);
    setResizable(false);

    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.fill = GridBagConstraints.BOTH;
    gbc.anchor = GridBagConstraints.CENTER;
    gbc.insets = new Insets(3,3,3,3);
    setLayout(gbl);

    hLabel = new Label("sf Firewall Control Panel", Label.CENTER);
    Utils.add_component(this, hLabel, gbl, gbc, 0, 0, 1, 1, 100, 100);
    Font hf = hLabel.getFont();
    hLabel.setFont(new Font(hf.getName(), Font.BOLD, hf.getSize()+3));
    Utils.add_component(this, 
      new Label("Version 0.3.0, February 28th 1997", Label.CENTER), 
      gbl, gbc, 0, 1, 1, 1, 100, 100);
    Utils.add_component(this, 
      new Label("Copyright \u00A9 1997 Roland E. Schmid", Label.CENTER), 
      gbl, gbc, 0, 2, 1, 1, 100, 100);

    gbc.fill = GridBagConstraints.NONE;
    Utils.add_component(this, new Button("OK"), gbl, gbc, 0, 3, 1, 1, 0, 0);

    pack();
  }

  public boolean action(Event evt, Object arg) {
    if (arg.equals("OK")) {
      dispose();
      return true;
    }
    else
      return super.action(evt, arg);
  }

  public boolean handleEvent(Event evt) {
    if (evt.id == Event.WINDOW_DESTROY && evt.target == this) {
      if (isEnabled())
        dispose();
      return true;
    }
    else
      return super.handleEvent(evt);
  }

  private Label hLabel;
      
}

