
/*  ----------------------------------------------------------------------
   sf Control Panel - A management software for sf Firewall
   Copyright (C) 1997 Roland E. Schmid <schmid@acm.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

package sfclasses;

import java.awt.*;
import java.awt.image.*;

/**
 * General drag and drop object that uses an icon to draw itself. This is
 * the parent class of Host, Net and Internet. The icons are stored as
 * static arrays in private classes, because the applet is not allowed
 * to load icons from the disk.
 * @version 1.0 03 Dec 1996
 * @author Roland E. Schmid
 */

public class IconObject extends ManageObject {

  /**
   * Initialize object
   */
  public IconObject() {
    // implicit call to super()
  }

  /**
   * Initialize icon<br>
   * The drag and drop panel calls this method.
   * @see DragDropObj
   */
  public void initImage(Component target, MediaTracker mt) {
    if ((target != null) && (iconLoaded == ICON_STATE_NONE)) {
      if (icon == null)
        if (iconName != null) 
          icon = Toolkit.getDefaultToolkit().getImage(iconName);
        else 
          icon = Acme.Utils.brokenImage(target);
      mt.addImage(icon, 0);
      iconLoaded = ICON_STATE_REQUESTED;
    }
  }

  /**
   * Draw icon<br>
   * The drag and drop panel calls this method.
   * @param g Graphics context of drag and drop canvas
   * @param x_offset Current horizontal offset of virtual viewport
   * @param y_offset Current vertical offst of virtual viewport
   * @see DragDropObj
   */
  public void draw(Graphics g, int x_offset, int y_offset) {
    if (iconLoaded == ICON_STATE_REQUESTED) {
      dX = icon.getWidth(null) / 2;
      dY = icon.getHeight(null) / 2;
      iconLoaded = ICON_STATE_LOADED;
    }
    if (iconLoaded != ICON_STATE_LOADED) 
      super.draw(g, x_offset, y_offset);
    else {
      g.drawImage(icon, actX-x_offset-dX, actY-y_offset-dY, null);
      if (isHighlighted) {
        Color savecolor = g.getColor();
        g.setColor(Color.red);
        g.drawRect(actX-x_offset-dX-1, actY-y_offset-dY-1, 2*dX+2, 2*dY+2);
        g.setColor(savecolor);
      }
    }
  }

  private static final int ICON_STATE_NONE = 0;
  private static final int ICON_STATE_REQUESTED = 1;
  private static final int ICON_STATE_LOADED = 2;

  protected Image icon;
  private protected int iconLoaded = ICON_STATE_NONE;
  private protected String iconName;

}

