
/*  ----------------------------------------------------------------------
   sf Control Panel - A management software for sf Firewall
   Copyright (C) 1997 Roland E. Schmid <schmid@acm.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

package sfclasses;

import java.awt.*;
import Acme.Widgets.*;

/**
 * This class describes a network element, this can contain many real nets
 * and hosts
 * @version 1.0 03 Dec 1996
 * @author Roland E. Schmid
 */

public class Net extends IconObject {

  /** 
   * Initialize object and icon
   */
  public Net() {
    //implicit call to super()
    if (bSource == null)
      bSource = new networkImageSource();
    icon = Toolkit.getDefaultToolkit().createImage(bSource);
  }

  // overriding Object methods

  public String toString() {
    return "Net: "+objectInfo();
  }

  /**
   * Show the network properties dialog. The drag and drop panel calls this
   * method when the user double clicks on the network icon in edit mode.
   * @param parent Parent frame (drag and drop panel)
   */
  public void execute(Frame parent) {
    NetProperties np;
    if (objectID.length() > 0)
      np = new NetProperties(parent, "Network "+objectID, this);
    else
      np = new NetProperties(parent, "Network properties", this);
    np.show();
  }

  // persistence methods
  /**
   * Write object data to a persistent output stream
   * @param ps Stream
   * @see PersistentOutputStream
   */
  public void write(PersistentOutputStream ps) {
    super.write(ps);
    ps.writePersistent(",NetAddresses=", NetAddresses);
  }

  /**
   * Read object data from a persistent input stream
   * @param ps Stream
   * @see PersistentInputStream
   */
  public void read(PersistentInputStream ps) throws java.io.IOException {
    super.read(ps);
    NetAddresses = (AddrList)ps.readPersistent(",NetAddresses=");
  }

  private static java.awt.image.ImageProducer bSource = null;

  // network properties
  protected AddrList NetAddresses = new AddrList();

}

// Network properties dialog box
class NetProperties extends Dialog {

  public NetProperties(Frame parent, String title, Net n) {
    super(parent, title, true);
    net = n;
    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.fill = GridBagConstraints.BOTH;
    gbc.insets = new Insets(5,5,5,5);
    setLayout(gbl);

    // Name panel
    Utils.add_component(this, new ImageLabel(net.icon), gbl, gbc, 0, 0, 1, 1, 0, 0);
    Utils.add_component(this, new Label("Identifier: "), gbl, gbc, 1, 0, 1, 1, 0, 0);
    IDtext = new TextField(net.objectID);
    Utils.add_component(this, IDtext, gbl, gbc, 2, 0, 3, 1, 100, 0);

    // Address panel
    Panel ap = net.NetAddresses.editPanel();
    Utils.add_component(this, ap, gbl, gbc, 0, 1, 3, 8, 80, 100);

    // Buttons
    OKbutton = new Button("OK");
    gbc.fill = GridBagConstraints.NONE;
    Utils.add_component(this, OKbutton, gbl, gbc, 0, 9, 5, 1, 0, 0);

    // Window size
    Graphics g = parent.getGraphics();
    FontMetrics fm = g.getFontMetrics();
    resize(fm.stringWidth("255.255.255.255/255.255.255.255   ") * 2,
           fm.getHeight() * 20 );
    g.dispose();
  }

  public boolean action(Event evt, Object arg) {
    if (evt.target==OKbutton) {  
      net.objectID = IDtext.getText().trim();
      dispose();
      return true;
    }
    else if (evt.target==IDtext) {
      net.objectID = ((String)arg).trim();
      setTitle("Network "+net.objectID);
      return true;
    }
    else
      return super.action(evt, arg);
  }

  public boolean handleEvent(Event evt) {
    if (evt.id == Event.WINDOW_DESTROY && evt.target == this) {
      if (isEnabled())
        dispose();
      return true;
    }
    else
      return super.handleEvent(evt);
  }

  private Net net;
  private Button OKbutton;
  private TextField IDtext;
} // NetProperties

// Network icon
class networkImageSource extends java.awt.image.MemoryImageSource {

  final static int bWidth = 32;
  final static int bHeight = 32;
  private static int[] bPixels = { // color model is AARRGGBB

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0x00ffffff, 0xff808080, 
    0xff808080, 0xff808080, 0xff808080, 0xff808080, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff808080, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff808080, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0x00ffffff, 

    0x00ffffff, 0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff00ffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff000000, 0x00ffffff, 

    0x00ffffff, 0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff00ffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff000000, 0x00ffffff, 

    0x00ffffff, 0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff00ffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff00ffff, 
    0xff000000, 0x00ffffff, 

    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 

    0xff000000, 0x00ffffff, 0xff808080, 0xff808080, 0xff808080, 
    0xff808080, 0xff808080, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0x00ffffff, 0xff808080, 0xff808080, 0xff808080, 0xff808080, 
    0xff808080, 0xff000000, 

    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff000000, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0xff808080, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0xff808080, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0xff000000, 0xff00ffff, 
    0xff00ffff, 0xff00ffff, 0xff00ffff, 0xff000000, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0x00ffffff, 0xff808080, 
    0xff808080, 0xff808080, 0xff808080, 0xff808080, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0xff000000, 0xff000000, 0xff000000, 
    0xff000000, 0xff000000, 0xff000000, 0xff000000, 0xff000000, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 

    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 0x00ffffff, 
    0x00ffffff, 0x00ffffff, 
    };

  public networkImageSource() {
    super( bWidth, bHeight, bPixels, 0, bWidth );
  }
}

