
/*  ----------------------------------------------------------------------
   sf Control Panel - A management software for sf Firewall
   Copyright (C) 1997 Roland E. Schmid <schmid@acm.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

package sfclasses;

import java.awt.*;

/**
 * Dialog Box to input a string<br>
 * The dialog box contains a text input field to enter a string, an OK
 * button and a Cancel button. It is a subclass of Frame because when
 * deriving it from Dialog, it does not work correctly with Netscape.
 * @version 1.0 26 Jan 1997
 * @author Roland E. Schmid
 */

public class StringDialog extends Frame {

    private String[] buttons;
    private TextField text;
    private int[] answers;

    public static final int OK = 0;
    public static final int CANCEL = 1;

    public StringDialog( Frame parent, String message) {
      setTitle("Enter text");
      build(message);
    }

    /**
     * Initialize dialog box<br>
     * After creating and showing the dialog, call getAnswer() or getString()
     * to wait until the user closes has finished.
     * @param parent Parent frame
     * @param title Window title string
     * @param message Prompt string
     */
    public StringDialog( Frame parent, String title, String message) {
      setTitle(title);
      build(message);
    }

    private void build( String message )
	{

	GridBagLayout gb = new GridBagLayout();
	setLayout( gb );
	GridBagConstraints gbc = new GridBagConstraints();
	gbc.insets = new Insets( 5, 5, 5, 5 );

        buttons = new String[2];
        buttons[0] = new String("OK");
        buttons[1] = new String("Cancel");
        answers = new int[2];
        answers[0] = OK;
        answers[1] = CANCEL;

	Label label = new Label( message );
        Utils.add_component(this, label, gb, gbc, 0, 0, 1, 1, 0, 0);

        text = new TextField(50);
        Utils.add_component(this, text, gb, gbc, 1, 0, 1, 1, 100, 0);

	Panel buttonPanel = new Panel();
	buttonPanel.setLayout( new FlowLayout( FlowLayout.LEFT ) );
	for ( int i = 0; i < buttons.length; i++ )
	    buttonPanel.add( new Button( buttons[i] ) );
	Utils.add_component(this, buttonPanel, gb, gbc, 0, 1, 2, 1, 100, 0);

        pack();

	}


    /** 
     * Event handler.
     */
    public boolean handleEvent( Event evt )
	{
	switch ( evt.id )
	    {
	    case Event.ACTION_EVENT:
	    for ( int i = 0; i < buttons.length; ++i )
		if ( evt.arg.equals( buttons[i] ) )
		    {
		    click( answers[i] );
		    return true;
		    }
            if (evt.target == text) {
              click(OK);
              return true;
            }   
	    break;
	    }
	return super.handleEvent( evt );
	}


    private boolean clicked = false;
    private int answer;

    private synchronized void click( int val )
	{
	answer = val;
	clicked = true;
	notify();
	hide();
	dispose();
	}

    /** 
     * Get the answer.
     * @return OK if the user pressed return or pushed the OK button,
     * Cancel if the user pushed the Cancel button. Do not call this
     * method from an event handler.
     */
    public synchronized int getAnswer()
	{
	while ( ! clicked )
	    {
	    try
		{
		wait();
		}
	    catch ( InterruptedException ignore ) {}
	    }
	return answer;
	}

    /**
     * Get the string the user has entered. Do not call this method 
     * from an event handler.
     * @return Entered string or null if the user has selected Cancel
     */
    public synchronized String getString() {
	while ( ! clicked )
	    {
	    try
		{
		wait();
		}
	    catch ( InterruptedException ignore ) {}
	    }
        if (answer == OK)
          return text.getText().trim();
        else
          return null;
	}


    }
