
/*  ----------------------------------------------------------------------
   sf Firewall Software -- a TCP/IP packet filter for Linux
   Copyright (C) 1997 Robert Muchsel and Roland Schmid

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Please address all correspondence concerning the software to 
   firewall-bugs@switch.ch.
   ----------------------------------------------------------------------  */

/*
 * sf Firewall Relay - Communication with Configuration Server and Client
 *
 */

#ifndef _SF_RELAY_H
#define _SF_RELAY_H

/*#define RELAY_DEBUG*/

#ifndef MAX
#define MAX(a, b)   ((a) > (b) ? (a) : (b))
#endif

struct serv_data {
  unsigned long magic;
  unsigned long command;
  unsigned long length;
  unsigned char data[0];
};

#define BUFFER_SIZE		4096
#define SERV_MAGIC		0xbedd1bedL
#define SERV_MAXLEN		BUFFER_SIZE - sizeof(struct serv_data)
#define CLIBUF_SIZE		1024
#define CLI_MAGIC		0xbadcafeL
#define CLI_MAXLEN		CLIBUF_SIZE - sizeof(struct serv_data)
#define MAX_TEMPFILES		20

/* server commands */
#define SERV_SERVER_HELLO	0x01L
#define SERV_RELAY_HELLO	0x02L
#define SERV_CLOSE		0x03L
#define SERV_CLOSE_ACK		0x04L
#define SERV_PING		0x05L
#define SERV_PING_REPLY		0x06L
#define SERV_GET_FILE		0x07L
#define SERV_FILE_DATA		0x08L
#define SERV_WRITE_FILE		0x09L
#define SERV_WRITE_OK		0x0AL
#define SERV_WRITE_FAIL		0x0BL
#define SERV_READ_ADDR		0x0CL
#define SERV_READ_RULES		0x0DL
#define SERV_READ_VARS		0x0EL
#define SERV_RECONFIG           0x0FL
#define SERV_CHECKCONFIG        0X10L
#define SERV_OK                 0X11L
#define SERV_ERROR              0x12L
#define SERV_READ_TCP		0x13L
#define SERV_KILL_TCP           0x14L
#define SERV_RESET_USAGE        0x15L

/* client commands */
#define CLI_OPEN_SERV		0x0100L
#define CLI_CLOSE_SERV		0x0200L
#define CLI_GET_FILE_TMP	0x0300L
#define CLI_FILE_TMP_NAME	0x0400L
#define CLI_GET_FILE    	0x0500L
#define CLI_FILE_DATA		0x0600L
#define CLI_DELETE_FILE		0x0700L
#define CLI_RESOLVE		0x0800L
#define CLI_RESOLVE_REPLY	0x0900L
#define CLI_WRITE_FILE		0x0A00L
#define CLI_WRITE_STATUS	0x0B00L
#define CLI_READ_ADDR		0x0C00L
#define CLI_READ_RULES		0x0D00L
#define CLI_READ_VARS		0x0E00L
#define CLI_WRITE_LOCAL_FILE	0x0F00L
#define CLI_RECONFIG            0x1000L
#define CLI_CHECKCONFIG         0x1100L
#define CLI_READ_TCP		0x1200L
#define CLI_KILL_TCP            0x1300L
#define CLI_RESET_USAGE         0x1400L
#define CLI_GET_LOCAL_FILE      0x1500L
#define CLI_GET_TEMPNAME        0x1600L
#define CLI_RESOLVE_IP          0x1700L
#define CLI_RESOLVE_SERVICE     0x1800L
#define CLI_RESOLVE_PORT        0x1900L

#define CLI_OK			0xA100L /* no error */
#define CLI_ERROR		0xA200L /* unspecified error */
#define CLI_ERROR_ISCONN	0xA300L /* invalid server address */
#define CLI_ERROR_OPENCONN	0xA400L /* cannot open connection to server */
#define CLI_ERROR_NOTCONN	0xA500L /* not connected to server */
#define CLI_ERROR_FILE		0xA600L /* error handling local file */
#define CLI_WAIT		0xA700L /* write status not yet available */

/* states */
#define STATE_NOCONN            0x00    /* socket not connected */
#define STATE_CONN              0x01    /* connection established */
#define STATE_CHILD             0x02    /* child is using connection */
#define STATE_USE_MASK          0x03    /* mask: server or child reading? */
#define STATE_WAITHELLO         0x04    /* waiting for hello */
#define STATE_WAITDATA          0x08    /* waiting for more data */
#define STATE_WAITPING          0x10    /* waiting for ping reply */
#define STATE_CLOSEWAIT         0x20    /* waiting for close ack */
#define STATE_RECEIVE_FILE	0x40	/* waiting for more file data */
#define STATE_RECEIVE_TMPFILE	0x80	/* waiting for more file data */
#define STATE_WRITE_FILE	0x100	/* writing file to server */

#endif
